utils

package
v0.0.0-...-e510100 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 26, 2024 License: GPL-3.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunCommand

func RunCommand(cmd string) error

runCommand executes a shell command and captures its output.

func UploadDirectory

func UploadDirectory(ctx context.Context, projectID *string, client *s3.Client, bucket, baseKey, dirPath string) error

uploadDirectory recursively uploads all files in a directory to S3.

Types

This section is empty.

Jump to